from setuptools import setup

setup(
    name='pythonthegathering',
    packages=['pythonthegathering'],
    version='1.2.1',
    description='Replaces everything good and practical about Python with MTG!',
    author='Theo Hamilton/linky00',
    author_email='linky00@plotholestudios.com',
    url='https://github.com/linky00/pythonthegathering',
    download_url='https://github.com/linky00/pythonthegathering/archive/v1.2.tar.gz',
    keywords='decorators mtg',
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6'
    ],
    license='MIT'
)
